@@ -25,7 +25,10 @@ FlatpakJobTransaction::FlatpakJobTransaction(FlatpakResource *app, Role role, bo
     }
 }
 
-FlatpakJobTransaction::~FlatpakJobTransaction() = default;
+FlatpakJobTransaction::~FlatpakJobTransaction()
+{
+    delete m_appJob;
+}
 
 void FlatpakJobTransaction::cancel()
 {
@@ -51,7 +54,7 @@ void FlatpakJobTransaction::finishTransaction()
 {
     if (m_appJob->result()) {
         AbstractResource::State newState = AbstractResource::None;
-        switch(role()) {
+        switch (role()) {
         case InstallRole:
         case ChangeAddonsRole:
             newState = AbstractResource::Installed;
@@ -70,5 +73,4 @@ void FlatpakJobTransaction::finishTransaction()
         }
         setStatus(DoneWithErrorStatus);
     }
-
 }
